# Text2Vec

All kinds of differing length of texts can be turned into vectors:
e.g. Word2Vec, Sentence2Vec, Doc2Vec, PDF2Vec

All kinds of differing models that have strengths in different departments:
e.g. BERT for , Word2Vec for Association,

All kinds of differing domain of texts can be turned into vectors:
e.g. Med2Vec
